==> litejs-18.2.6.tgz: package/app/auth.js <==


/*
 * Authentication - login + password (who you are)
 * Authorization  - permissions (what you are allowed to do)
 * Accounting     - consumed resources (session statistics and usage for authorization control, billing, trend analysis, resource utilization, and capacity planning activities)
 */


module.exports = auth

function auth(req, res, next, options) {
	var authorization = req.headers["authorization"]

	if (authorization) {
		authorization = authorization.split(/\s+/)

		if (authorization[0] == "Session") {
			options.sessionStorage.get(authorization[1], handleSession)
		} else if (authorization[0] == "Basic") {
			return res.sendStatus(501) // Not Implemented

			var user_and_pass = new Buffer(authorization[1], "base64").toString()
			, name = user_and_pass.split(":")[0]
			, token = crypto.createHash("sha1").update(user_and_pass).digest("hex")

		} else if (authorization[0] == "Bearer") {
			return res.sendStatus(501) // Not Implemented
		} else if (authorization[0] == "MAC") {
			// http://tools.ietf.org/html/rfc6749#section-7.1
			return res.sendStatus(501) // Not Implemented
		} else {
			// res.setHeader("WWW-Authenticate", 'Basic realm="LiteJS"')
			res.end()
		}
	} else {
		req.session = {}
		next()
	}

	function handleSession(err, session) {
		req.session = session = session || {}
		session.seen = +req.date
		if (session && session.userId) {
			options.userStorage.get(session.userId, handleUser)
		} else {
			next()
		}
	}

	function handleUser(err, user) {
		req.user = user
		next()
	}
}

==> litejs-19.3.1.tgz: package/app/auth.js <==


/*
 * Authentication - login + password (who you are)
 * Authorization  - permissions (what you are allowed to do)
 * Accounting     - consumed resources (session statistics and usage for authorization control, billing, trend analysis, resource utilization, and capacity planning activities)
 */


module.exports = auth

function auth(req, res, next, options) {
	var authorization = req.headers["authorization"]

	if (authorization) {
		authorization = authorization.split(/\s+/)

		if (authorization[0] == "Session") {
			options.sessionStorage.get(authorization[1], handleSession)
		} else if (authorization[0] == "Basic") {
			return res.sendStatus(501) // Not Implemented

			var user_and_pass = Buffer.from(authorization[1], "base64").toString()
			, name = user_and_pass.split(":")[0]
			, token = crypto.createHash("sha1").update(user_and_pass).digest("hex")

		} else if (authorization[0] == "Bearer") {
			return res.sendStatus(501) // Not Implemented
		} else if (authorization[0] == "MAC") {
			// http://tools.ietf.org/html/rfc6749#section-7.1
			return res.sendStatus(501) // Not Implemented
		} else {
			// res.setHeader("WWW-Authenticate", 'Basic realm="LiteJS"')
			res.end()
		}
	} else {
		req.session = {}
		next()
	}

	function handleSession(err, session) {
		req.session = session = session || {}
		session.seen = +req.date
		if (session && session.userId) {
			options.userStorage.get(session.userId, handleUser)
		} else {
			next()
		}
	}

	function handleUser(err, user) {
		req.user = user
		next()
	}
}
